==> ejc-supbid-impl-3.0.1-20220124.080804-130-sources.jar: com/ejianc/business/supbid/notice/bean/SignEntity.java <==
package com.ejianc.business.supbid.notice.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 报名实体
 * 
 * @author generator
 * 
 */
 @TableName("ejc_supbid_sign")
public class SignEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="notice_id")
    private java.lang.Long noticeId; // 主表主键
    @TableField(value="source_id")
    private java.lang.String sourceId; // 招标信息主键
//    @TableField(value="source_tenant_id")
//    private java.lang.String sourceTenantId;
    @TableField(value="source_supplier_id")
    private java.lang.String sourceSupplierId;//供应商来源主键
    @TableField(value="sign_status")
    private java.lang.Integer signStatus; // 状态(0-已报名，1-待报价，2-洽商谈判，3-报价中，4-已定标，5-已淘汰)
    @TableField(value="out_reason")
    private java.lang.String outReason; // 淘汰原因
    @TableField(value="sign_employee_id")
    private java.lang.Long signEmployeeId; // 报名联系人
    @TableField(value="sign_employee_name")
    private java.lang.String signEmployeeName; // 报名联系人名称
    @TableField(value="sign_employee_mobile")
    private java.lang.String signEmployeeMobile; // 报名联系人电话
    @TableField(value="invoice_note")
    private java.lang.String invoiceNote; // 发票说明
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    @TableField(value="sign_time")
    private java.util.Date signTime; // 报名时间
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    @TableField(value="scheme_time")
    private java.util.Date schemeTime; // 报价时间
    @TableField(value="sign_id")
    private java.lang.Long signId; // 报名操作人
    @TableField(value="sign_name")
    private java.lang.String signName; // 报名操作人名称
    @TableField(value="scheme_id")
    private java.lang.Long schemeId; // 报价操作人
    @TableField(value="scheme_name")
    private java.lang.String schemeName; // 报价操作人名称

//    public String getSourceTenantId() {
//        return sourceTenantId;
//    }
//
//    public void setSourceTenantId(String sourceTenantId) {
//        this.sourceTenantId = sourceTenantId;
//    }

    public String getSourceSupplierId() {
        return sourceSupplierId;
    }

    public void setSourceSupplierId(String sourceSupplierId) {
        this.sourceSupplierId = sourceSupplierId;
    }

    /**
     * 主表主键
     */
    public java.lang.Long getNoticeId() {
        return noticeId;
    }

    /**
     * 主表主键
     */
    public void setNoticeId(java.lang.Long noticeId) {
        this.noticeId = noticeId;
    }
    /**
     * 招标信息主键
     */
    public java.lang.String getSourceId() {
        return sourceId;
    }

    /**
     * 招标信息主键
     */
    public void setSourceId(java.lang.String sourceId) {
        this.sourceId = sourceId;
    }
    /**
     * 状态(0-已报名，1-待报价，2-洽商谈判，3-报价中，4-已定标，5-已淘汰)
     */
    public java.lang.Integer getSignStatus() {
        return signStatus;
    }

    /**
     * 状态(0-已报名，1-待报价，2-洽商谈判，3-报价中，4-已定标，5-已淘汰)
     */
    public void setSignStatus(java.lang.Integer signStatus) {
        this.signStatus = signStatus;
    }
    /**
     * 淘汰原因
     */
    public java.lang.String getOutReason() {
        return outReason;
    }

    /**
     * 淘汰原因
     */
    public void setOutReason(java.lang.String outReason) {
        this.outReason = outReason;
    }
    /**
     * 报名联系人
     */
    public Long getSignEmployeeId() {
        return signEmployeeId;
    }

    public void setSignEmployeeId(Long signEmployeeId) {
        this.signEmployeeId = signEmployeeId;
    }

    public String getSignEmployeeName() {
        return signEmployeeName;
    }

    public void setSignEmployeeName(String signEmployeeName) {
        this.signEmployeeName = signEmployeeName;
    }

    public String getSignEmployeeMobile() {
        return signEmployeeMobile;
    }

    public void setSignEmployeeMobile(String signEmployeeMobile) {
        this.signEmployeeMobile = signEmployeeMobile;
    }

    /**
     * 发票说明
     */
    public java.lang.String getInvoiceNote() {
        return invoiceNote;
    }

    /**
     * 发票说明
     */
    public void setInvoiceNote(java.lang.String invoiceNote) {
        this.invoiceNote = invoiceNote;
    }
    /**
     * 报名时间
     */
    public java.util.Date getSignTime() {
        return signTime;
    }

    /**
     * 报名时间
     */
    public void setSignTime(java.util.Date signTime) {
        this.signTime = signTime;
    }
    /**
     * 报价时间
     */
    public java.util.Date getSchemeTime() {
        return schemeTime;
    }

    /**
     * 报价时间
     */
    public void setSchemeTime(java.util.Date schemeTime) {
        this.schemeTime = schemeTime;
    }
    /**
     * 报名操作人
     */
    public java.lang.Long getSignId() {
        return signId;
    }

    /**
     * 报名操作人
     */
    public void setSignId(java.lang.Long signId) {
        this.signId = signId;
    }
    /**
     * 报名操作人名称
     */
    public String getSignName() {
        return signName;
    }

    public void setSignName(String signName) {
        this.signName = signName;
    }

    /**
     * 报价操作人
     */
    public Long getSchemeId() {
        return schemeId;
    }

    public void setSchemeId(Long schemeId) {
        this.schemeId = schemeId;
    }

    /**
     * 报价操作人名称
     */
    public java.lang.String getSchemeName() {
        return schemeName;
    }

    /**
     * 报价操作人名称
     */
    public void setSchemeName(java.lang.String schemeName) {
        this.schemeName = schemeName;
    }
    
}

==> ejc-supbid-impl-3.0.1-20231117.091130-245-sources.jar: com/ejianc/business/supbid/notice/bean/SignEntity.java <==
package com.ejianc.business.supbid.notice.bean;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 报名实体
 * 
 * @author generator
 * 
 */
 @TableName("ejc_supbid_sign")
public class SignEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="notice_id")
    private java.lang.Long noticeId; // 主表主键
    @TableField(value="source_id")
    private java.lang.String sourceId; // 招标信息主键
//    @TableField(value="source_tenant_id")
//    private java.lang.String sourceTenantId;
    @TableField(value="source_supplier_id")
    private java.lang.String sourceSupplierId;//供应商来源主键
    @TableField(value="sign_status")
    private java.lang.Integer signStatus; // 状态(0-已报名，1-待报价，2-洽商谈判，3-报价中，4-已定标，5-已淘汰)
    @TableField(value="out_reason")
    private java.lang.String outReason; // 淘汰原因
    @TableField(value="sign_employee_id")
    private java.lang.Long signEmployeeId; // 报名联系人
    @TableField(value="sign_employee_name")
    private java.lang.String signEmployeeName; // 报名联系人名称
    @TableField(value="sign_employee_mobile")
    private java.lang.String signEmployeeMobile; // 报名联系人电话
    @TableField(value="invoice_note")
    private java.lang.String invoiceNote; // 发票说明
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    @TableField(value="sign_time")
    private java.util.Date signTime; // 报名时间
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    @TableField(value="scheme_time")
    private java.util.Date schemeTime; // 报价时间
    @TableField(value="sign_id")
    private java.lang.Long signId; // 报名操作人
    @TableField(value="sign_name")
    private java.lang.String signName; // 报名操作人名称
    @TableField(value="scheme_id")
    private java.lang.Long schemeId; // 报价操作人
    @TableField(value="scheme_name")
    private java.lang.String schemeName; // 报价操作人名称


    @TableField(value="mny_sub_tender")
    private BigDecimal mnySubTender; //投标总价（无税）
    @TableField(value="mny_sub_tender_name")
    private java.lang.String mnySubTenderName; // 投标总价（无税）大写
    @TableField(value="tax_mny_sub_tender")
    private BigDecimal taxMnySubTender; // 投标总价
    @TableField(value="tax_mny_sub_tender_name")
    private java.lang.String taxMnySubTenderName; // 投标总价大写

    @TableField(value="price_type")
    private java.lang.String priceType; // 新增单价确定方式

    @TableField(value="quality_promise")
    private java.lang.String qualityPromise; // 质量承诺

    @TableField(value="safe_promise")
    private java.lang.String safePromise; // 安全文明施工承诺

    @TableField(value="duration_promise")
    private java.lang.String durationPromise; // 工期承诺

    @TableField(value="margin_type")
    private java.lang.String marginType; // 投标保证金形式

    @TableField(value="other_promise")
    private java.lang.String otherPromise; //其他承诺

    public BigDecimal getMnySubTender() {
        return mnySubTender;
    }

    public void setMnySubTender(BigDecimal mnySubTender) {
        this.mnySubTender = mnySubTender;
    }

    public String getMnySubTenderName() {
        return mnySubTenderName;
    }

    public void setMnySubTenderName(String mnySubTenderName) {
        this.mnySubTenderName = mnySubTenderName;
    }

    public BigDecimal getTaxMnySubTender() {
        return taxMnySubTender;
    }

    public void setTaxMnySubTender(BigDecimal taxMnySubTender) {
        this.taxMnySubTender = taxMnySubTender;
    }

    public String getTaxMnySubTenderName() {
        return taxMnySubTenderName;
    }

    public void setTaxMnySubTenderName(String taxMnySubTenderName) {
        this.taxMnySubTenderName = taxMnySubTenderName;
    }

    public String getPriceType() {
        return priceType;
    }

    public void setPriceType(String priceType) {
        this.priceType = priceType;
    }

    public String getQualityPromise() {
        return qualityPromise;
    }

    public void setQualityPromise(String qualityPromise) {
        this.qualityPromise = qualityPromise;
    }

    public String getSafePromise() {
        return safePromise;
    }

    public void setSafePromise(String safePromise) {
        this.safePromise = safePromise;
    }

    public String getDurationPromise() {
        return durationPromise;
    }

    public void setDurationPromise(String durationPromise) {
        this.durationPromise = durationPromise;
    }

    public String getMarginType() {
        return marginType;
    }

    public void setMarginType(String marginType) {
        this.marginType = marginType;
    }

    public String getOtherPromise() {
        return otherPromise;
    }

    public void setOtherPromise(String otherPromise) {
        this.otherPromise = otherPromise;
    }

    //    public String getSourceTenantId() {
//        return sourceTenantId;
//    }
//
//    public void setSourceTenantId(String sourceTenantId) {
//        this.sourceTenantId = sourceTenantId;
//    }

    public String getSourceSupplierId() {
        return sourceSupplierId;
    }

    public void setSourceSupplierId(String sourceSupplierId) {
        this.sourceSupplierId = sourceSupplierId;
    }

    /**
     * 主表主键
     */
    public java.lang.Long getNoticeId() {
        return noticeId;
    }

    /**
     * 主表主键
     */
    public void setNoticeId(java.lang.Long noticeId) {
        this.noticeId = noticeId;
    }
    /**
     * 招标信息主键
     */
    public java.lang.String getSourceId() {
        return sourceId;
    }

    /**
     * 招标信息主键
     */
    public void setSourceId(java.lang.String sourceId) {
        this.sourceId = sourceId;
    }
    /**
     * 状态(0-已报名，1-待报价，2-洽商谈判，3-报价中，4-已定标，5-已淘汰)
     */
    public java.lang.Integer getSignStatus() {
        return signStatus;
    }

    /**
     * 状态(0-已报名，1-待报价，2-洽商谈判，3-报价中，4-已定标，5-已淘汰)
     */
    public void setSignStatus(java.lang.Integer signStatus) {
        this.signStatus = signStatus;
    }
    /**
     * 淘汰原因
     */
    public java.lang.String getOutReason() {
        return outReason;
    }

    /**
     * 淘汰原因
     */
    public void setOutReason(java.lang.String outReason) {
        this.outReason = outReason;
    }
    /**
     * 报名联系人
     */
    public Long getSignEmployeeId() {
        return signEmployeeId;
    }

    public void setSignEmployeeId(Long signEmployeeId) {
        this.signEmployeeId = signEmployeeId;
    }

    public String getSignEmployeeName() {
        return signEmployeeName;
    }

    public void setSignEmployeeName(String signEmployeeName) {
        this.signEmployeeName = signEmployeeName;
    }

    public String getSignEmployeeMobile() {
        return signEmployeeMobile;
    }

    public void setSignEmployeeMobile(String signEmployeeMobile) {
        this.signEmployeeMobile = signEmployeeMobile;
    }

    /**
     * 发票说明
     */
    public java.lang.String getInvoiceNote() {
        return invoiceNote;
    }

    /**
     * 发票说明
     */
    public void setInvoiceNote(java.lang.String invoiceNote) {
        this.invoiceNote = invoiceNote;
    }
    /**
     * 报名时间
     */
    public java.util.Date getSignTime() {
        return signTime;
    }

    /**
     * 报名时间
     */
    public void setSignTime(java.util.Date signTime) {
        this.signTime = signTime;
    }
    /**
     * 报价时间
     */
    public java.util.Date getSchemeTime() {
        return schemeTime;
    }

    /**
     * 报价时间
     */
    public void setSchemeTime(java.util.Date schemeTime) {
        this.schemeTime = schemeTime;
    }
    /**
     * 报名操作人
     */
    public java.lang.Long getSignId() {
        return signId;
    }

    /**
     * 报名操作人
     */
    public void setSignId(java.lang.Long signId) {
        this.signId = signId;
    }
    /**
     * 报名操作人名称
     */
    public String getSignName() {
        return signName;
    }

    public void setSignName(String signName) {
        this.signName = signName;
    }

    /**
     * 报价操作人
     */
    public Long getSchemeId() {
        return schemeId;
    }

    public void setSchemeId(Long schemeId) {
        this.schemeId = schemeId;
    }

    /**
     * 报价操作人名称
     */
    public java.lang.String getSchemeName() {
        return schemeName;
    }

    /**
     * 报价操作人名称
     */
    public void setSchemeName(java.lang.String schemeName) {
        this.schemeName = schemeName;
    }
    
}
